==> dasu_1.0.jar: edu/northwestern/dasu/measurement/DasuPingModuleV2.java <==
/**
 * Dasu Project
 *
 * File:         DasuPingModuleV2.java
 * RCS:          $Id: DasuPingModuleV2.java,v 1.6 2010/06/03 01:50:50 mas939 Exp $
 * Description:  OptimalEdge class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Apr 15, 2010 at 07:38:30 PM
 * Language:     Java
 * Package:      edu.northwestern.ono.experiment
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2010, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.measurement;


import java.util.ArrayList;
import java.util.Hashtable;
import java.util.List;
import edu.northwestern.dasu.Main;
import edu.northwestern.dasu.MainGeneric;
import edu.northwestern.dasu.drools.FactPingProbeResult;
import edu.northwestern.dasu.stats.Statistics;
import edu.northwestern.dasu.util.Pair;
import edu.northwestern.dasu.util.PingManager;
import edu.northwestern.dasu.util.Util;
import edu.northwestern.dasu.util.Util.PingResponse;

/**
 * @author Mario Sanchez &lt;msanchez@u.northwestern.edu&gt;
 * 
 *         The HamecaPingModuleV2 class manages the set of 
 *         Pings performed by the peer.
 */

public class DasuPingModuleV2 extends DasuProbeModule {	
		
	private class TaskEntry {
		
		public Integer taskId;
		public String ipAddress;
		
		public TaskEntry(String ip, Integer taskId) {
			this.taskId = taskId;
			this.ipAddress = ip;
		}
	}
	
	public Hashtable<Long, FactPingProbeResult> pingResultTable;
	private ArrayList<TaskEntry> toDoIpList = new ArrayList<TaskEntry>();
	private static DasuPingModuleV2 self;

	public DasuPingModuleV2() {
		super("DasuPingModule");
		this.pi = MainGeneric.getPluginInterface();
		pingResultTable = new Hashtable<Long, FactPingProbeResult>();
		
		active = true;
	}
	
	public synchronized static DasuPingModuleV2 getInstance() {
		if (self == null) {
			self = new DasuPingModuleV2();
			self.setDaemon(true);
			return self;
		} else {
			return self;
		}
	}

	@Override
	public void run() {
		
	  while (!MainGeneric.isShuttingDown() && isActive()) {
		 
			TaskEntry taskEntry = null;
;			synchronized (toDoIpList) {
				while ((toDoIpList.size()==0) && !MainGeneric.isShuttingDown()) {
					try {
						toDoIpList.wait(sleepInterval*1000);
					} catch (InterruptedException e) {
						self = null;
						return;
					}
				}
				
				taskEntry = toDoIpList.remove(0);
				if (DEBUG)
					System.out.println("HamecaPingModule: Ping server " + taskEntry.ipAddress );
			}
			
			if (taskEntry.ipAddress.equals("HALT"))
				return;

			if (Main.isValidIp(taskEntry.ipAddress)) {
				probeIp(taskEntry.ipAddress, taskEntry.taskId);
			} 
			else {
				updatePingResultQueue(taskEntry.ipAddress, -1, taskEntry.taskId);
			}

	  } // end while active
		
	  self = null;
	}
		
	@Override
	public void probeAll(List<String> list, Integer taskId) {

		synchronized (toDoIpList) {
			for (String ip : list)
				toDoIpList.add(new TaskEntry(ip, taskId));
			toDoIpList.notifyAll();
		}
	}
	
	@Override
	public void probeWithPriority(String ip, Integer taskId) {
		
		synchronized (toDoIpList) {
			toDoIpList.add(new TaskEntry(ip, taskId));
			toDoIpList.notifyAll();
		}		
	}

	@Override
	public void probe(String ip, Integer taskId) {

		synchronized (toDoIpList) {
			toDoIpList.add(new TaskEntry(ip, taskId));
			toDoIpList.notifyAll();
		}
	}
	
	@Override
	protected Object probeIp(final String ipAddress, final Integer taskId) {

		PingManager.getInstance().doPing(ipAddress, 
				pi, new PingResponse() {

					public void response(double rtt) {
						if (rtt >= 0) {
							Statistics.getInstance()
									.addPingResultDasu(
											getIp(),
											ipAddress,
											rtt,
											Util.currentGMTTime(),
											1,
											taskId);
						}

						updatePingResultQueue(ipAddress, rtt, taskId);
						Statistics.getInstance().addPeer(ipAddress);
					}					
				}
		);
		
		return null;

	}

	private void updatePingResultQueue(String ipAddressResponse, double rtt, int taskId) {

		Long id = System.nanoTime();
		pingResultTable.put(id, new FactPingProbeResult(ipAddressResponse, rtt));
		
		synchronized(AMCoordinatorV2.events) {
			AMCoordinatorV2.events.add(
				new Pair<Long, EventType>(id, EventType.HPM_RESULT));
			AMCoordinatorV2.events.notifyAll();
		}
	}
	
	
	@Override
	public void stopModule() {
		
		setActive(false);
		synchronized(toDoIpList) {
			toDoIpList.add(new TaskEntry("HALT", -1));
			toDoIpList.notify();
		}
	
		self = null;
	}
		
}

==> dasu_2.02.jar: edu/northwestern/dasu/measurement/DasuPingModuleV2.java <==
/**
 * Dasu Project
 *
 * File:         DasuPingModuleV2.java
 * RCS:          $Id: DasuPingModuleV2.java,v 1.8 2010/11/01 15:37:00 mas939 Exp $
 * Description:  OptimalEdge class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Apr 15, 2010 at 07:38:30 PM
 * Language:     Java
 * Package:      edu.northwestern.ono.experiment
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2010, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.measurement;


import java.util.ArrayList;
import java.util.Hashtable;
import java.util.List;
import edu.northwestern.dasu.Main;
import edu.northwestern.dasu.MainGeneric;
import edu.northwestern.dasu.drools.FactPingProbeResult;
import edu.northwestern.dasu.stats.Statistics;
import edu.northwestern.dasu.util.Pair;
import edu.northwestern.dasu.util.PingManager;
import edu.northwestern.dasu.util.Util;
import edu.northwestern.dasu.util.Util.PingResponse;

/**
 * @author Mario Sanchez &lt;msanchez@u.northwestern.edu&gt;
 * 
 *         The DasuPingModuleV2 class manages the set of 
 *         Pings performed by the peer.
 */

public class DasuPingModuleV2 extends DasuProbeModule {	
		
	private class TaskEntry {
		
		public Integer taskId;
		public String ipAddress;
		
		public TaskEntry(String ip, Integer taskId) {
			this.taskId = taskId;
			this.ipAddress = ip;
		}
	}
	
	public Hashtable<Long, FactPingProbeResult> pingResultTable;
	private ArrayList<TaskEntry> toDoIpList = new ArrayList<TaskEntry>();
	private static DasuPingModuleV2 self;

	public DasuPingModuleV2() {
		super("DasuPingModule");
		this.pi = MainGeneric.getPluginInterface();
		pingResultTable = new Hashtable<Long, FactPingProbeResult>();
		
		active = true;
	}
	
	public synchronized static DasuPingModuleV2 getInstance() {
		if (self == null) {
			self = new DasuPingModuleV2();
			self.setDaemon(true);
			return self;
		} else {
			return self;
		}
	}

	@Override
	public void run() {
		
	  while (!MainGeneric.isShuttingDown() && isActive()) {
		 
			TaskEntry taskEntry = null;
;			synchronized (toDoIpList) {
				while ((toDoIpList.size()==0) && !MainGeneric.isShuttingDown()) {
					try {
						toDoIpList.wait(sleepInterval*1000);
					} catch (InterruptedException e) {
						self = null;
						return;
					}
				}
				
				taskEntry = toDoIpList.remove(0);
				if (DEBUG)
					System.out.println("DasuPingModule: Ping server " + taskEntry.ipAddress );
			}
			
			if (taskEntry.ipAddress.equals("HALT"))
				return;

			if (Main.isValidIp(taskEntry.ipAddress)) {
				probeIp(taskEntry.ipAddress, taskEntry.taskId);
			} 
			else {
				updatePingResultQueue(taskEntry.ipAddress, -1, taskEntry.taskId);
			}

	  } // end while active
		
	  self = null;
	}
		
	@Override
	public void probeAll(List<String> list, Integer taskId) {

		synchronized (toDoIpList) {
			for (String ip : list)
				toDoIpList.add(new TaskEntry(ip, taskId));
			toDoIpList.notifyAll();
		}
	}
	
	@Override
	public void probeWithPriority(String ip, Integer taskId) {
		
		synchronized (toDoIpList) {
			toDoIpList.add(new TaskEntry(ip, taskId));
			toDoIpList.notifyAll();
		}		
	}

	@Override
	public void probe(String ip, Integer taskId) {

		synchronized (toDoIpList) {
			toDoIpList.add(new TaskEntry(ip, taskId));
			toDoIpList.notifyAll();
		}
	}
	
	@Override
	protected Object probeIp(final String ipAddress, final Integer taskId) {

		PingManager.getInstance().doPing(ipAddress, 
				pi, new PingResponse() {

					public void response(double rtt) {
						if (rtt >= 0) {
							Statistics.getInstance()
									.addPingResultDasu(
											getIp(),
											ipAddress,
											rtt,
											Util.currentGMTTime(),
											1,
											taskId);
						}

						updatePingResultQueue(ipAddress, rtt, taskId);
						//Statistics.getInstance().addPeer(ipAddress);
						Statistics.getInstance().addPeerForLookup(ipAddress);
					}					
				}
		);
		
		return null;

	}

	private void updatePingResultQueue(String ipAddressResponse, double rtt, int taskId) {

		Long id = System.nanoTime();
		pingResultTable.put(id, new FactPingProbeResult(ipAddressResponse, rtt));
		
		synchronized(AMCoordinatorV2.events) {
			AMCoordinatorV2.events.add(
				new Pair<Long, EventType>(id, EventType.HPM_RESULT));
			AMCoordinatorV2.events.notifyAll();
		}
	}
	
	
	@Override
	public void stopModule() {
		
		setActive(false);
		synchronized(toDoIpList) {
			toDoIpList.add(new TaskEntry("HALT", -1));
			toDoIpList.notify();
		}
	
		self = null;
	}
		
}
